@@ -72,7 +72,7 @@ recode_num <- function(X, ..., default = NULL, missing = NULL) {
   }
   if(is.list(X)) return(duplAttributes(lapply(unattrib(X), repfun), X))
   if(!is.numeric(X)) stop("X needs to be numeric or a list")
-  return(repfun(X))
+  repfun(X)
 }
 
 recode_char <- function(X, ..., default = NULL, missing = NULL, regex = FALSE) {
@@ -204,7 +204,7 @@ recode_char <- function(X, ..., default = NULL, missing = NULL, regex = FALSE) {
   }
   if(is.list(X)) return(duplAttributes(lapply(unattrib(X), repfun), X))
   if(!is.character(X)) stop("X needs to be character or a list")
-  return(repfun(X))
+  repfun(X)
 }
 
 replace_NA <- function(X, value) {
@@ -224,7 +224,11 @@ replace_Inf <- function(X, value = NA, replace.nan = FALSE) {
   if(replace.nan) return(`[<-`(X, is.infinite(X) | is.nan(X), value = value)) #  !is.finite(X) also replaces NA
   `[<-`(X, is.infinite(X), value = value)
 }
-replace_non_finite <- function(X, value = NA, replace.nan = TRUE) replace_Inf(X, value, replace.nan)
+
+replace_non_finite <- function(X, value = NA, replace.nan = TRUE) {
+  .Deprecated("replace_Inf")
+  replace_Inf(X, value, replace.nan)
+}
 
 replace_outliers <- function(X, limits, value = NA, single.limit = c("SDs", "min", "max", "overall_SDs")) {
   ll <- length(limits)
@@ -242,9 +246,9 @@ replace_outliers <- function(X, limits, value = NA, single.limit = c("SDs", "min
               num <- vapply(unattrib(X), is.numeric, TRUE)
               num <- if(inherits(X, "grouped_df")) num & !fgroup_vars(X, "logical") else
                       num & attr(attr(X, "index"), "names") %!in% attr(X, "names")
-              clx <- class(X)
+              clx <- oldClass(X)
               STDXnum <- fscale(fcolsubset(X, num))
-              class(X) <- NULL
+              oldClass(X) <- NULL
               X[num] <- mapply(function(x, y) `[<-`(x, abs(y) > limits, value = value), unattrib(X)[num], unattrib(STDXnum), SIMPLIFY = FALSE)
               `oldClass<-`(X, clx)
              } else duplAttributes(lapply(unattrib(X), function(x) if(is.numeric(x)) `[<-`(x, abs(fscaleCpp(x)) > limits, value = value) else x), X)
@@ -270,6 +274,7 @@ comp <- function(x, val) do.call(cbind, lapply(x, `==`, val))
 comp_grepl <- function(x, val) do.call(cbind, lapply(x, function(y) grepl(val, y)))
 
 Recode <- function(X, ..., copy = FALSE, reserve.na.nan = TRUE, regex = FALSE) {
+  .Deprecated("recode_num, recode_char")
   if(missing(...)) stop("Recode requires arguments of the form: value = replacement")
   if(is.list(X) && !inherits(X, "data.frame")) stop("Recode only works with atomic objects or data.frames")
   args <- list(...)
