@@ -1,10 +1,10 @@
 ## ---- echo = FALSE, message = FALSE, warning=FALSE-------------------------------------------------
 library(vars)
 library(dplyr)  # Needed because otherwise dplyr is loaded in benchmark chunk not run on CRAN !!
+library(magrittr)
 library(microbenchmark) # Same thing
 library(collapse)
 library(data.table)
-setDTthreads(1) # for good comparisons ...
 B <- collapse::B # making sure it masks vars::B by loading into GE
 knitr::opts_chunk$set(error = FALSE, message = FALSE, warning = FALSE, 
                       comment = "#", tidy = FALSE, cache = FALSE, collapse = TRUE,
@@ -39,7 +39,7 @@ head(wlddev)
 namlab(wlddev, class = TRUE)
 
 ## --------------------------------------------------------------------------------------------------
-# A detailed statistical description, executed at the same speed as summary(wlddev)
+# A fast and detailed statistical description
 descr(wlddev)
 
 ## --------------------------------------------------------------------------------------------------
@@ -104,7 +104,7 @@ cat(funique(GGDC10S$Country, ordered = TRUE))
 
 
 ## --------------------------------------------------------------------------------------------------
-# Converting data to percentages of overall VA / EMP, dapply keeps the attributes, see section 4.1
+# Converting data to percentages of overall VA / EMP, dapply keeps the attributes, see section 6.1
 pGGDC10S <- dapply(GGDC10S[6:15], `*`, 100 / GGDC10S$SUM) 
 # Summarizing the sectoral data by variable, overall, between and within countries
 su <- qsu(pGGDC10S, by = GGDC10S$Variable, pid = GGDC10S[c("Variable","Country")], higher = TRUE) 
@@ -143,17 +143,22 @@ plotGGDC("BWA")
 
 
 ## --------------------------------------------------------------------------------------------------
-head(fselect(wlddev, country, year, PCGDP:ODA), 3)
+library(magrittr) # Pipe operators
+fselect(wlddev, country, year, PCGDP:ODA) %>% head(2)
 
-head(fselect(wlddev, -country, -year, -(PCGDP:ODA)), 3)
+fselect(wlddev, -country, -year, -(PCGDP:ODA)) %>% head(2)
+
+library(microbenchmark)
+microbenchmark(fselect = collapse::fselect(wlddev, country, year, PCGDP:ODA),
+               select = dplyr::select(wlddev, country, year, PCGDP:ODA))
 
 ## --------------------------------------------------------------------------------------------------
 # Computing the log of columns
 fselect(wlddev, PCGDP:ODA) <- lapply(fselect(wlddev, PCGDP:ODA), log)
-head(wlddev, 3)
+head(wlddev, 2)
 # Efficient deleting
 fselect(wlddev, country, year, PCGDP:ODA) <- NULL
-head(wlddev, 3)
+head(wlddev, 2)
 rm(wlddev)
 
 ## --------------------------------------------------------------------------------------------------
@@ -164,13 +169,13 @@ fselect(wlddev, PCGDP:ODA, return = "logical")
 fselect(wlddev, PCGDP:ODA, return = "named_logical")
 
 ## --------------------------------------------------------------------------------------------------
-get_vars(wlddev, 9:12) %>% head(2)
-get_vars(wlddev, c("PCGDP","LIFEEX","GINI","ODA")) %>% head(2)
-get_vars(wlddev, "[[:upper:]]", regex = TRUE) %>% head(2)
-get_vars(wlddev, "PC|LI|GI|OD", regex = TRUE) %>% head(2)
+get_vars(wlddev, 9:12) %>% head(1)
+get_vars(wlddev, c("PCGDP","LIFEEX","GINI","ODA")) %>% head(1)
+get_vars(wlddev, "[[:upper:]]", regex = TRUE) %>% head(1)
+get_vars(wlddev, "PC|LI|GI|OD", regex = TRUE) %>% head(1)
 # Same as above, vectors of regular expressions are sequentially passed to grep
-get_vars(wlddev, c("PC","LI","GI","OD"), regex = TRUE) %>% head(2)
-get_vars(wlddev, is.numeric) %>% head(2)
+get_vars(wlddev, c("PC","LI","GI","OD"), regex = TRUE) %>% head(1)
+get_vars(wlddev, is.numeric) %>% head(1)
 
 # Returning other information
 get_vars(wlddev, is.numeric, return = "names")
@@ -183,12 +188,6 @@ get_vars(wlddev, 9:12) <- NULL
 head(wlddev, 2)
 rm(wlddev)
 
-## --------------------------------------------------------------------------------------------------
-series <- wlddev[9:12]
-microbenchmark(get_vars(wlddev, 9:12), wlddev[9:12])
-microbenchmark(get_vars(wlddev, 9:12) <- series, wlddev[9:12] <- series)
-microbenchmark(get_vars(wlddev, 9:12) <- get_vars(wlddev, 9:12), wlddev[9:12] <- wlddev[9:12])
-
 ## --------------------------------------------------------------------------------------------------
 head(num_vars(wlddev), 2)
 head(cat_vars(wlddev), 2)
@@ -202,90 +201,141 @@ fact_vars(wlddev) <- fact_vars(wlddev)
 fsubset(GGDC10S, Variable == "VA" & Year > 1990, Country, Year, AGR:GOV) %>% head(2)
 # Same thing
 fsubset(GGDC10S, Variable == "VA" & Year > 1990, -(Regioncode:Variable), -(OTH:SUM)) %>% head(2)
-# It is also possible to use standard evaluation with fsubset
-fsubset(GGDC10S, 1:2, 6:16)
-fsubset(GGDC10S, 1:2, c("AGR","MIN"))
 
 ## --------------------------------------------------------------------------------------------------
-ss(GGDC10S, 1:2, 6:16)
+ss(GGDC10S, 1:2, 6:16)  # or fsubset(GGDC10S, 1:2, 6:16)
 ss(GGDC10S, -(1:2), c("AGR","MIN")) %>% head(2)
 
 ## --------------------------------------------------------------------------------------------------
-library(data.table)
-GGDC10S <- qDT(GGDC10S) # See section 3
 microbenchmark(base = subset(GGDC10S, Variable == "VA" & Year > 1990, AGR:SUM), 
-               collapse = fsubset(GGDC10S, Variable == "VA" & Year > 1990, AGR:SUM),
-               data.table = GGDC10S[Variable == "VA" & Year > 1990, AGR:SUM])
-# Note: The difference between fsubset and [.data.table becomes negligible as data grow large, but on smaller data it matters.
+               collapse = fsubset(GGDC10S, Variable == "VA" & Year > 1990, AGR:SUM))
 
-## --------------------------------------------------------------------------------------------------
-class(GGDC10S) <- "data.frame"
 microbenchmark(GGDC10S[1:10, 1:10], ss(GGDC10S, 1:10, 1:10))
 
 ## --------------------------------------------------------------------------------------------------
-# Computing Agricultural percentage and deleting the original series
-ftransform(GGDC10S, AGR_perc = AGR / SUM * 100, AGR = NULL) %>% tail(2)
+roworder(GGDC10S, -Variable, Country) %>% ss(1:2, 1:8)
+
+microbenchmark(collapse = collapse::roworder(GGDC10S, -Variable, Country), 
+               dplyr = dplyr::arrange(GGDC10S, desc(Variable), Country))
+
+## --------------------------------------------------------------------------------------------------
+# Same as above
+roworderv(GGDC10S, c("Variable", "Country"), decreasing = c(TRUE, FALSE)) %>% ss(1:2, 1:8)
+
+## --------------------------------------------------------------------------------------------------
+# If length(neworder) < fnrow(data), the default (pos = "front") brings rows to the front
+roworderv(GGDC10S, neworder = which(GGDC10S$Country == "GHA")) %>% ss(1:2, 1:8)
+
+# pos = "end" brings rows to the end
+roworderv(GGDC10S, neworder = which(GGDC10S$Country == "BWA"), pos = "end") %>% ss(1:2, 1:8)
+
+# pos = "exchange" arranges selected rows in the order they are passed, without affecting other rows
+roworderv(GGDC10S, neworder = with(GGDC10S, c(which(Country == "GHA"), 
+                                              which(Country == "BWA"))), pos = "exchange") %>% ss(1:2, 1:8)
+
+## --------------------------------------------------------------------------------------------------
+# The default is again pos = "front" which brings selected columns to the front / left
+colorder(GGDC10S, Variable, Country, Year) %>% head(2)
+
+## --------------------------------------------------------------------------------------------------
+ftransform(GGDC10S, AGR_perc = AGR / SUM * 100, # Computing Agricultural percentage
+                    Year = as.integer(Year),    # Coercing Year to integer
+                    AGR = NULL) %>% tail(2)     # Deleting column AGR
+
 # Computing scalar results replicates them
 ftransform(GGDC10S, MIN_mean = fmean(MIN), Intercept = 1) %>% tail(2)
 
 ## --------------------------------------------------------------------------------------------------
-# Computing a new column and deleting some others by refernce
+GGDC10S %>% ftransform(num_vars(.) %>% lapply(log)) %>% tail(2)
+GGDC10S %>% ftransform(num_vars(.) %>% lapply(sum, na.rm = TRUE)) %>% tail(2)
+rm(GGDC10S)
+
+## --------------------------------------------------------------------------------------------------
+# Computing a new column and deleting some others by reference
 settransform(GGDC10S, FIRE_MAN = FIRE / MAN,
                       Regioncode = NULL, Region = NULL)
 tail(GGDC10S, 2)
+
+# Bulk-processing the data into percentage terms
+settransform(GGDC10S, fselect(GGDC10S, AGR:SUM) %>% lapply(`*`, 100/.$SUM))
+tail(GGDC10S, 2)
+
+# Same thing via replacement 
+ftransform(GGDC10S) <- fselect(GGDC10S, AGR:SUM) %>% lapply(`*`, 100/.$SUM)
+# Or using double pipes
+GGDC10S %<>% ftransform(fselect(., AGR:SUM) %>% lapply(`*`, 100/.$SUM))
 rm(GGDC10S)
 
 ## --------------------------------------------------------------------------------------------------
 fcompute(GGDC10S, AGR_perc = AGR / SUM * 100, FIRE_MAN = FIRE / MAN) %>% tail(2)
 
 ## --------------------------------------------------------------------------------------------------
-# Very efficient adding logged versions of some variables
-add_vars(wlddev) <- add_stub(lapply(unclass(wlddev)[9:12], log10), "log10.")
+# Efficient adding logged versions of some variables
+add_vars(wlddev) <- get_vars(wlddev, 9:12) %>% lapply(log10) %>% add_stub("log10.")
 head(wlddev, 2)
 rm(wlddev)
 
 ## --------------------------------------------------------------------------------------------------
-add_vars(wlddev, "front") <- add_stub(lapply(unclass(wlddev)[9:12], log10), "log10.")
+add_vars(wlddev, "front") <- get_vars(wlddev, 9:12) %>% lapply(log10) %>% add_stub("log10.")
 head(wlddev, 2)
 rm(wlddev)
 
-add_vars(wlddev, c(10,12,14,16)) <- add_stub(lapply(unclass(wlddev)[9:12], log10), "log10.")
+add_vars(wlddev, c(10,12,14,16)) <- get_vars(wlddev, 9:12) %>% lapply(log10) %>% add_stub("log10.")
 head(wlddev, 2)
 rm(wlddev)
 
 ## --------------------------------------------------------------------------------------------------
-add_vars(wlddev,  add_stub(lapply(unclass(wlddev)[9:12], log), "log."), 
-                  add_stub(lapply(unclass(wlddev)[9:12], log10), "log10.")) %>% head(2)
+add_vars(wlddev, get_vars(wlddev, 9:12) %>% lapply(log) %>% add_stub("log."),
+                 get_vars(wlddev, 9:12) %>% lapply(log10) %>% add_stub("log10.")) %>% head(2)
 
-add_vars(wlddev,  add_stub(lapply(unclass(wlddev)[9:12], log), "log."), 
-                  add_stub(lapply(unclass(wlddev)[9:12], log10), "log10."),
+add_vars(wlddev,  get_vars(wlddev, 9:12) %>% lapply(log) %>% add_stub("log."), 
+                  get_vars(wlddev, 9:12) %>% lapply(log10) %>% add_stub("log10."),
          pos = c(10,13,16,19,11,14,17,20)) %>% head(2)
 
 identical(cbind(wlddev, wlddev), add_vars(wlddev, wlddev))
 microbenchmark(cbind(wlddev, wlddev), add_vars(wlddev, wlddev))
 
 ## --------------------------------------------------------------------------------------------------
-microbenchmark(standard = tfm(gv(wlddev,9:12), ODA_GDP = ODA/PCGDP),
+frename(GGDC10S, AGR = Agriculture, MIN = Mining) %>% head(2)
+frename(GGDC10S, tolower) %>% head(2)
+frename(GGDC10S, tolower, cols = .c(AGR, MIN)) %>% head(2)
+
+## --------------------------------------------------------------------------------------------------
+setrename(GGDC10S, AGR = Agriculture, MIN = Mining)
+head(GGDC10S, 2)
+rm(GGDC10S)
+
+## --------------------------------------------------------------------------------------------------
+microbenchmark(standard = tfm(gv(wlddev, 9:12), ODA_GDP = ODA/PCGDP),
                piped = get_vars(wlddev, 9:12) %>% ftransform(ODA_GDP = ODA/PCGDP))
 
 ## --------------------------------------------------------------------------------------------------
 microbenchmark(na_omit(wlddev, na.attr = TRUE), na.omit(wlddev))
 
 ## --------------------------------------------------------------------------------------------------
-na_omit(wlddev, cols = c("PCGDP","LIFEEX")) %>% head(2)
+na_omit(wlddev, cols = .c(PCGDP, LIFEEX)) %>% head(2)
 # only removing missing data from numeric columns -> same and slightly faster than na_omit(wlddev) 
 na_omit(wlddev, cols = is.numeric) %>% head(2)
 
+## --------------------------------------------------------------------------------------------------
+funique(GGDC10S$Variable)              # Unique values in order of appearance
+funique(GGDC10S$Variable, sort = TRUE) # Sorted unique values
+
+# If all values/rows are unique, the original data is returned (no copy)
+identical(funique(GGDC10S), GGDC10S)
+
+# Can remove duplicate rows by a subset of columns
+funique(GGDC10S, cols = .c(Country, Variable)) %>% ss(1:2, 1:8)
+funique(GGDC10S, cols = .c(Country, Variable), sort = TRUE) %>% ss(1:2, 1:8)
+
 ## --------------------------------------------------------------------------------------------------
 # Efficient replacing missing values with NA
 microbenchmark(replace_NA(GGDC10S, 0))
 
-# Generating log-transformed sectoral data: Some NaN and Inf values generated
-logGGDC <- `get_vars<-`(GGDC10S, 6:16, value = lapply(unclass(GGDC10S)[6:16], log))
-tail(logGGDC, 3)
-
-# Replacing infinite (and NaN) values with NA (default)
-microbenchmark(replace_Inf(GGDC10S), replace_Inf(GGDC10S, replace.nan = TRUE))
+# Adding log-transformed sectoral data: Some NaN and Inf values generated
+add_vars(GGDC10S, 6:16*2-5) <- fselect(GGDC10S, AGR:SUM) %>% lapply(log) %>% replace_Inf %>% add_stub("log.") 
+head(GGDC10S, 2)
+rm(GGDC10S)
 
 ## --------------------------------------------------------------------------------------------------
 month.name
@@ -293,24 +343,24 @@ recode_char(month.name, ber = "C", "^J" = "A", default = "B", regex = TRUE)
 
 ## --------------------------------------------------------------------------------------------------
 # replace all values below 2 and above 100 with NA
-replace_outliers(mtcars, c(2, 100)) %>% head        
+replace_outliers(mtcars, c(2, 100)) %>% head(3)        
 
 # replace all value smaller than 2 with NA
-replace_outliers(mtcars, 2, single.limit = "min") %>% head
+replace_outliers(mtcars, 2, single.limit = "min") %>% head(3)
 
 # replace all value larger than 100 with NA
-replace_outliers(mtcars, 100, single.limit = "max") %>% head
+replace_outliers(mtcars, 100, single.limit = "max") %>% head(3)
 
 # replace all values above or below 3 column-standard-deviations from the column-mean with NA
-replace_outliers(mtcars, 3) %>% tail                        
+replace_outliers(mtcars, 3) %>% tail(3)                        
                                                     
 
 ## --------------------------------------------------------------------------------------------------
 str(EuStockMarkets)
-# Efficient Conversion of data.frames and matrices to data.table
+# Efficient Conversion of data frames and matrices to data.table
 microbenchmark(qDT(wlddev), qDT(EuStockMarkets), as.data.table(wlddev), as.data.frame(EuStockMarkets))
 
-# Converting a time-series to data.frame
+# Converting a time series to data.frame
 head(qDF(AirPassengers))
 
 ## --------------------------------------------------------------------------------------------------
@@ -327,34 +377,42 @@ head(qDF(N_distinct, "variable"))
 microbenchmark(mrtl(EuStockMarkets))
 
 ## --------------------------------------------------------------------------------------------------
-microbenchmark(rowSums(qM(mtcars)), rowSums(as.matrix(mtcars)))
+microbenchmark(rowSums(qM(mtcars)), rowSums(mtcars))
 
 ## --------------------------------------------------------------------------------------------------
+# Converting from character
 str(wlddev$country)
 fNdistinct(wlddev$country)
-
 microbenchmark(qF(wlddev$country), as.factor(wlddev$country))
 
+# Converting from numeric
+str(wlddev$PCGDP)
+fNdistinct(wlddev$PCGDP)
+microbenchmark(qF(wlddev$PCGDP), as.factor(wlddev$PCGDP))
+
+
 ## ----eval=FALSE------------------------------------------------------------------------------------
 #  FUN(x, g = NULL, [w = NULL,] TRA = NULL, [na.rm = TRUE,] use.g.names = TRUE, drop = TRUE)
 #  
 
 ## --------------------------------------------------------------------------------------------------
+fmean(mtcars$mpg) # Vector
+
 fmean(mtcars)
 
 fmean(mtcars, drop = FALSE)  # This returns a 1-row data-frame
 
-m <- qM(mtcars) 
+m <- qM(mtcars) # Generate matrix
 fmean(m)
 
-fmean(mtcars, drop = FALSE)  # This returns a 1-row matrix
+fmean(m, drop = FALSE)  # This returns a 1-row matrix
 
 ## --------------------------------------------------------------------------------------------------
-weights <- abs(rnorm(fnrow(mtcars))) # fnrow is a bit faster for data.frame's
+weights <- abs(rnorm(fnrow(mtcars))) # fnrow is a bit faster for data frames
 
 fmean(mtcars, w = weights) # Weighted mean
+fmedian(mtcars, w = weights) # Weighted median
 fsd(mtcars, w = weights) # Frequency-weighted standard deviation
-fsum(mtcars, w = weights) # Total
 fmode(mtcars, w = weights) # Weighted statistical mode (i.e. the value with the largest sum of weights)
 
 ## --------------------------------------------------------------------------------------------------
@@ -367,15 +425,19 @@ ind <- fselect(mtcars, cyl, vs, am, return = "indices")
 fmean(get_vars(mtcars, -ind), get_vars(mtcars, ind))  
 
 ## --------------------------------------------------------------------------------------------------
-# This creates a factor
+# This creates a factor, na.exclude = FALSE attaches a class 'na.included'
 f <- qF(mtcars$cyl, na.exclude = FALSE)
 # The 'na.included' attribute skips a missing value check on this factor
-str(f)
+attributes(f)
 # Saving data without grouping columns
 dat <- get_vars(mtcars, -ind)
 # Grouped standard-deviation
 fsd(dat, f)
 
+# Without option na.exclude = FALSE, anyNA needs to be called on the factor (noticeable on larger data).
+f2 <- qF(mtcars$cyl)
+microbenchmark(fsd(dat, f), fsd(dat, f2))
+
 ## --------------------------------------------------------------------------------------------------
 # This creates a 'GRP' object. 
 g <- GRP(mtcars, ~ cyl + vs + am) # Using the formula interface, could also use c("cyl","vs","am") or c(2,8:9)
@@ -389,7 +451,7 @@ plot(g)
 fsd(dat, g)
 
 # Grouped computation with and without prior grouping
-microbenchmark(fsd(dat, g), fsd(dat, GRP(mtcars, ind)))
+microbenchmark(fsd(dat, g), fsd(dat, get_vars(mtcars, ind)))
 
 ## --------------------------------------------------------------------------------------------------
 gmtcars <- fgroup_by(mtcars, cyl, vs, am)
@@ -400,12 +462,22 @@ head(fgroup_vars(gmtcars))
 fmedian(gmtcars, keep.group_vars = FALSE)
 
 ## --------------------------------------------------------------------------------------------------
-dat <- fselect(mtcars, mpg, disp)
+# Standard evaluation
+dat <- get_vars(mtcars, c("mpg", "disp"))
+add_vars(g[["groups"]],
+         add_stub(fmean(dat, g, use.g.names = FALSE), "mean_"),
+         add_stub(fsd(dat, g, use.g.names = FALSE), "sd_"),
+         add_stub(fmin(dat, g, use.g.names = FALSE), "min_"),
+         add_stub(fmax(dat, g, use.g.names = FALSE), "max_"))
 
-add_vars(add_stub(fmean(dat, g), "mean_"),
-         add_stub(fsd(dat, g), "sd_"),
-         add_stub(fmin(dat, g), "min_"),
-         add_stub(fmax(dat, g), "max_"))
+# Non-Standard evaluation
+fgroup_by(mtcars, cyl, vs, am) %>% fselect(mpg, disp) %>% {
+  add_vars(fgroup_vars(., "unique"),
+           fmean(., keep.group_vars = FALSE) %>% add_stub("mean_"),
+           fsd(., keep.group_vars = FALSE) %>% add_stub("sd_"),
+           fmin(., keep.group_vars = FALSE) %>% add_stub("min_"),
+           fmax(., keep.group_vars = FALSE) %>% add_stub("max_"))
+}
 
 ## --------------------------------------------------------------------------------------------------
 # Grouped and weighted mean and sd and grouped min and max
@@ -423,13 +495,13 @@ add_vars(g[["groups"]],
          add_stub(fmax(dat, g, use.g.names = FALSE), "max_"),
          pos = c(4,8,5,9,6,10,7,11))
 
-# We're still well in the microsecond domain. 
+
+## --------------------------------------------------------------------------------------------------
 microbenchmark(call = add_vars(g[["groups"]],
          add_stub(fmean(dat, g, weights, use.g.names = FALSE), "w_mean_"),
          add_stub(fsd(dat, g, weights, use.g.names = FALSE), "w_sd_"),
          add_stub(fmin(dat, g, use.g.names = FALSE), "min_"),
-         add_stub(fmax(dat, g, use.g.names = FALSE), "max_"),
-         pos = c(4,8,5,9,6,10,7,11)))
+         add_stub(fmax(dat, g, use.g.names = FALSE), "max_")))
 
 ## --------------------------------------------------------------------------------------------------
 head(add_vars(get_vars(mtcars, ind),
@@ -449,6 +521,22 @@ add_vars(mtcars, pos) <- c(add_stub(fmean(dat, g, weights, "-"), "w_demean_"),
 head(mtcars)
 rm(mtcars)
 
+## --------------------------------------------------------------------------------------------------
+# 2 different grouped and weighted computations (mutate operations) performed in one call
+settransform(mtcars, carb_dwmed_cyl = fmedian(carb, cyl, weights, "-"),
+                     carb_wsd_vs_am = fsd(carb, list(vs, am), weights, "replace"))
+
+# Multivariate
+settransform(mtcars, c(fmedian(list(carb_dwmed_cyl = carb, mpg_dwmed_cyl = mpg), cyl, weights, "-"),
+                      fsd(list(carb_wsd_vs_am = carb, mpg_wsd_vs_am = mpg), list(vs, am), weights, "replace")))
+
+# Nested (Computing the weighted 3rd quartile of mpg, grouped by cyl and carb being greater than it's weighted median, grouped by vs)
+settransform(mtcars, 
+ mpg_gwQ3_cyl = fnth(mpg, 0.75, list(cyl, carb > fmedian(carb, vs, weights, 1L)), weights, 1L))
+
+head(mtcars)
+rm(mtcars)
+
 ## --------------------------------------------------------------------------------------------------
 collap(mtcars, mpg + disp ~ cyl + vs + am, list(fmean, fsd, fmin, fmax), w = weights, keep.col.order = FALSE)
 
@@ -522,22 +610,22 @@ BY(miris, f, quantile, expand.wide = TRUE)[,1:5]
 BY(miris, f, quantile, expand.wide = TRUE, return = "list")[1:2] # list of matrices
 
 ## data.frame method
-BY(num_vars(iris), f, sum)             # Also returns a data.fram etc...
+BY(num_vars(iris), f, sum)             # Also returns a data.frame etc...
 
 ## Conversions
 identical(BY(num_vars(iris), f, sum), BY(miris, f, sum, return = "data.frame"))
 identical(BY(miris, f, sum), BY(num_vars(iris), f, sum, return = "matrix"))
 
 ## --------------------------------------------------------------------------------------------------
-# Note: All examples below generalize to vectors or data.frames
-stats <- fmean(miris)            # Savig stats
+# Note: All examples below generalize to vectors or data frames
+stats <- fmean(miris)            # Saving stats
 head(TRA(miris, stats, "-"), 3)  # Centering. Same as sweep(miris, 2, stats, "-")
 
 ## --------------------------------------------------------------------------------------------------
 # 3 ways of centering data
 all_identical(TRA(miris, fmean(miris), "-"),
               fmean(miris, TRA = "-"),   # better for any operation if the stats are not needed
-              fwithin(miris))            # fastest, fwithin is discussed in section 4.5
+              fwithin(miris))            # fastest, fwithin is discussed in section 6.5
 
 # Simple replacing [same as fmean(miris, TRA = "replace") or fbetween(miris)]
 head(TRA(miris, fmean(miris), "replace"), 3)
@@ -561,10 +649,10 @@ head(TRA(miris, fmean(miris, f), "-+", f), 3)
 head(TRA(TRA(miris, fmean(miris, f), "-", f), fmean(miris), "+"), 3) # Same thing done manually!
 
 # This group-centers data on the overall median!
-head(fmedian(miris, f, "-+"), 3)
+head(fmedian(miris, f, TRA = "-+"), 3)
 
 ## --------------------------------------------------------------------------------------------------
-# fsccale doesn't rename columns
+# fscale doesn't rename columns
 head(fscale(mtcars),2)
 
 # By default adds a prefix
@@ -630,7 +718,7 @@ par(oldpar)
 
 ## --------------------------------------------------------------------------------------------------
 # When using operators in formulas, we need to remove missing values beforehand to obtain the same results as a Fixed-Effects package
-data <- na_omit(get_vars(wlddev, c("iso3c","year","PCGDP","LIFEEX")))
+data <- na_omit(fselect(wlddev, iso3c, year, PCGDP, LIFEEX))
 
 # classical lm() -> iso3c is a factor, creates a matrix of 200+ country dummies.
 coef(lm(PCGDP ~ LIFEEX + iso3c, data))[1:2]
@@ -665,7 +753,7 @@ coef(lm(PCGDP ~ LIFEEX + HDB(LIFEEX, list(iso3c, year)), data))
 ## --------------------------------------------------------------------------------------------------
 # The syntax is fFtest(y, exc, X, full.df = TRUE). 'exc' are exclusion restrictions.
 # full.df = TRUE means count degrees of freedom in the same way as if dummies were created
-fFtest(data$PCGDP, data$year, get_vars(data, c("LIFEEX","iso3c")))
+data %$% fFtest(PCGDP, year, list(LIFEEX, iso3c))
 
 ## --------------------------------------------------------------------------------------------------
 wlddev$year <- as.numeric(wlddev$year)
@@ -685,18 +773,18 @@ head(HDW(iris[1:2], iris[3:5]))
 ## --------------------------------------------------------------------------------------------------
 mts <- psmat(wlddev, PCGDP ~ iso3c, ~ year)
 str(mts)
-plot(mts, main = vlabels(wlddev)[9], xlab = "Year")
+plot(log10(mts), main = paste("Log10", vlabels(wlddev$PCGDP)), xlab = "Year")
 
 ## --------------------------------------------------------------------------------------------------
-# Get panel-series array
+# Get panel series array
 psar <- psmat(wlddev, ~ iso3c, ~ year, cols = 9:12)
 str(psar)
 plot(psar)
 
 ## ---- fig.height=7---------------------------------------------------------------------------------
-# Plot array of Panel-Series aggregated by region:
-plot(psmat(collap(wlddev, ~region + year, cols = 9:12),
-           ~region, ~year), legend = TRUE, labs = vlabels(wlddev)[9:12])
+# Plot array of Panel Series aggregated by region:
+collap(wlddev, ~region + year, cols = 9:12) %>% psmat(~region, ~year) %>%
+  plot(legend = TRUE, labs = vlabels(wlddev)[9:12])
 
 ## --------------------------------------------------------------------------------------------------
 # This gives list of ps-matrices
@@ -707,9 +795,9 @@ str(psml, give.attr = FALSE)
 head(unlist2d(psml, idcols = "Variable", row.names = "Country"))[1:10]
 
 ## --------------------------------------------------------------------------------------------------
-# Panel-ACF of GDP per Capia
+# Panel-ACF of GDP per Capita
 psacf(wlddev, PCGDP ~ iso3c, ~year)
-# Panel-Parial-ACF of GDP per Capia
+# Panel-Partial-ACF of GDP per Capia
 pspacf(wlddev, PCGDP ~ iso3c, ~year)
 # Panel- Cross-Correlation function of GDP per Capia and Life-Expectancy
 psccf(wlddev$PCGDP, wlddev$LIFEEX, wlddev$iso3c, wlddev$year)
@@ -723,13 +811,10 @@ L(AirPassengers)
 # 3 identical ways of computing 1 lag
 all_identical(flag(AirPassengers), L(AirPassengers), F(AirPassengers,-1))
 
-# 3 identical ways of computing 1 lead
-all_identical(flag(AirPassengers, -1), L(AirPassengers, -1), F(AirPassengers))
-
 # 1 lead and 3 lags - output as matrix
 head(L(AirPassengers, -1:3))
 
-# ... this is still a time-series object:
+# ... this is still a time series object:
 attributes(L(AirPassengers, -1:3))
 
 ## --------------------------------------------------------------------------------------------------
@@ -766,7 +851,7 @@ tryCatch(flag(1:6, 1, g, t = c(1,2,3,1,2,4)),
          error = function(e) e)
 
 ## --------------------------------------------------------------------------------------------------
-# Different ways of regressing GDP on its's lags and life-Expectancy and it's lags
+# Different ways of regressing GDP on it's lags and life-Expectancy and it's lags
 
 # 1 - Precomputing lags
 summary(lm(PCGDP ~ ., L(wlddev, 0:2, PCGDP + LIFEEX ~ iso3c, ~ year, keep.ids = FALSE)))
@@ -783,20 +868,22 @@ summary(lm(PCGDP ~ L(PCGDP,1:2,g,t) + L(LIFEEX,0:2,g,t), wlddev))
 plot(stl(AirPassengers, "periodic"))
 
 ## --------------------------------------------------------------------------------------------------
-fFtest(AirPassengers, qF(cycle(AirPassengers)), poly(seq_along(AirPassengers), 3))
+f <- qF(cycle(AirPassengers))
+fFtest(fgrowth(AirPassengers), f)
 
 ## --------------------------------------------------------------------------------------------------
-plot(G(AirPassengers, c(0,1,12)))
+G(AirPassengers, c(0, 1, 12)) %>% cbind(W.G1 = W(G(AirPassengers), f)) %>% 
+  plot(main = "Growth Rate of Airpassengers")
 
 ## --------------------------------------------------------------------------------------------------
 plot(D(AirPassengers, c(1,12), 1:2))
 
 ## --------------------------------------------------------------------------------------------------
 # sequence of leaded/lagged and iterated differences
-head(D(AirPassengers, -2:2, 1:3))
+y = 1:10
+D(y, -2:2, 1:3)
 
 ## --------------------------------------------------------------------------------------------------
-y = 1:10
 g = rep(1:2, each = 5)
 t = rep(1:5, 2)
 
@@ -829,7 +916,7 @@ sec <- c("AGR","MAN","WRT","CON","TRA","FIRE")
 # This creates a data.frame containing the value added of the 6 most important non-government sectors
 data <- na_omit(fsubset(GGDC10S, Variable == "VA", c("Country","Year", sec)), cols = sec)
 # Let's look at the log VA in agriculture across countries:
-AGRmat <- log(psmat(data, AGR ~ Country, ~ Year, transpose = TRUE))   # Converting to panel-series matrix
+AGRmat <- log(psmat(data, AGR ~ Country, ~ Year, transpose = TRUE))   # Converting to panel series matrix
 plot(AGRmat)
 
 ## --------------------------------------------------------------------------------------------------
@@ -839,7 +926,7 @@ AGRmat <- dapply(AGRmat, fHDwithin, poly(seq_row(AGRmat), 3), fill = TRUE)
 plot(AGRmat)
 
 ## --------------------------------------------------------------------------------------------------
-# Standadizing the cubic log-detrended data
+# Standardizing the cubic log-detrended data
 AGRmat <- fscale(AGRmat)
 plot(AGRmat)
 
@@ -857,7 +944,7 @@ plot(psmat(data, ~Country, ~Year))
 ## --------------------------------------------------------------------------------------------------
 # This adds one lag of all series to the data
 add_vars(data) <- L(data, 1, ~ Country, ~ Year, keep.ids = FALSE)
-# This removes missing values from all but the first row and drops identifier columns (vars is made for time-series without gaps)
+# This removes missing values from all but the first row and drops identifier columns (vars is made for time series without gaps)
 data <- rbind(ss(data, 1, -(1:2)), na_omit(ss(data, -1, -(1:2))))
 head(data)
 
@@ -888,7 +975,7 @@ serial.test(pVAR)
 corr <- fsubset(GGDC10S, Variable == "VA") %>%   # Subset rows: Only VA
            fgroup_by(Country) %>%                # Group by country
                 get_vars(sec) %>%                # Select the 6 sectors
-                   fgrowth %>%                   # Compute Sectoral growth rates (a time-variable can be passsed, but not necessary here as the data is ordered)
+                   fgrowth %>%                   # Compute Sectoral growth rates (a time-variable can be passed, but not necessary here as the data is ordered)
                       fscale %>%                 # Scale and center (i.e. standardize)
                          pwcor                   # Compute Pairwise correlations
 
@@ -901,8 +988,13 @@ corr
 # The rest is unknown (i.e. will be estimated)
 corr[corr > 0 & corr < 1] <- NA
 
+# Using a diagonal shock vcov matrix (standard assumption for SVAR)
+Bmat <- diag(6)
+diag(Bmat) <- NA
+
+
 # This estimates the Panel-SVAR using Maximum Likelihood:
-pSVAR <- SVAR(pVAR, Amat = unclass(corr), estmethod = "direct")
+pSVAR <- SVAR(pVAR, Amat = unclass(corr), Bmat = Bmat, estmethod = "direct")
 pSVAR
 
 ## --------------------------------------------------------------------------------------------------
@@ -939,7 +1031,7 @@ str(pSVAR$var$varresult$STD.HDW.AGR$residuals)
 resid <- get_elem(pSVAR, "residuals")
 str(resid, give.attr = FALSE)
 
-# Qick conversion to matrix and plotting
+# Quick conversion to matrix and plotting
 plot.ts(qM(resid), main = "Panel-VAR Residuals")
 
 ## --------------------------------------------------------------------------------------------------
@@ -960,35 +1052,25 @@ str(pIRF, give.attr = FALSE)
 # Pool-out top-level atomic elements in the list
 str(atomic_elem(pIRF))
 
-## --------------------------------------------------------------------------------------------------
-# Plot the forecast-error variance decmpositions
-plot(pFEVD)
-
 ## --------------------------------------------------------------------------------------------------
 # Computing the cumulative impact after 10 periods
 list_elem(pIRF) %>%                            # Pull out the sublist elements containing the IRF coefficients + CI's
   rapply2d(function(x) round(fsum(x), 2)) %>%  # Recursively apply the column-sums to coefficient matrices (could also use colSums)
   unlist2d(c("Type", "Impulse"))               # Recursively row-bind the result to a data.frame and add identifier columns
-                             # Round result to 2 digits
 
 ## --------------------------------------------------------------------------------------------------
 # This binds the matrices after adding integer row-names to them to a data.table
 
 data <- pIRF$irf %>%                      # Get only the coefficient matrices, discard the confidence bounds
-         lapply(setRownames) %>%          # Add integer rownames: setRownames(object, nm = seq_row(object))
            unlist2d(idcols = "Impulse",   # Recursive unlisting to data.table creating a factor id-column
-                    row.names = "Time",   # and saving the generated rownames in a variable called 'Time'
+                    row.names = "Time",   # and saving generated rownames in a variable called 'Time'
                     id.factor = TRUE,     # -> Create Id column ('Impulse') as factor
                     DT = TRUE)            # -> Output as data.table (default is data.frame)
 
-head(data)
+head(data, 3)
 
-# Coercing Time to numeric (from character)
-data$Time <- as.numeric(data$Time)
-
-# Using data.table's melt
-data <- melt(data, 1:2)
-head(data)
+data <- melt(data, 1:2)                   # Using data.table's melt
+head(data, 3)
 
 # Here comes the plot:
   ggplot(data, aes(x = Time, y = value, color = Impulse)) +
@@ -1008,13 +1090,9 @@ head(data)
 
 
 ## --------------------------------------------------------------------------------------------------
-# Rewriting more compactly...
-data <- unlist2d(lapply(pFEVD, setRownames), idcols = "variable", row.names = "Time",
-                 id.factor = TRUE, DT = TRUE)
-data$Time <- as.numeric(data$Time)
-head(data)
-
-data <- melt(data, 1:2, variable.name = "Sector")
+data <- unlist2d(pFEVD, idcols = "variable", row.names = "Time", id.factor = TRUE, DT = TRUE) %>% 
+            melt(c("variable", "Time"), variable.name = "Sector") 
+head(data, 3)
 
 # Here comes the plot:
   ggplot(data, aes(x = Time, y = value, fill = Sector)) +
