@@ -37,6 +37,10 @@ test_that("ffirst performs like basefirst (defined above)", {
   expect_equal(ffirst(m, na.rm = FALSE), dapply(m, basefirst))
   expect_equal(ffirst(mNA, na.rm = FALSE), dapply(mNA, basefirst))
   expect_equal(ffirst(mNA), dapply(mNA, basefirst, na.rm = TRUE))
+  expect_equal(ffirst(data, drop = FALSE), dapply(data, basefirst, na.rm = TRUE, drop = FALSE))
+  expect_equal(ffirst(data, na.rm = FALSE, drop = FALSE), dapply(data, basefirst, drop = FALSE))
+  expect_equal(ffirst(dataNA, na.rm = FALSE, drop = FALSE), dapply(dataNA, basefirst, drop = FALSE))
+  expect_equal(ffirst(dataNA, drop = FALSE), dapply(dataNA, basefirst, na.rm = TRUE, drop = FALSE))
   expect_equal(ffirst(x, f), BY(x, f, basefirst, na.rm = TRUE))
   expect_equal(ffirst(x, f, na.rm = FALSE), BY(x, f, basefirst))
   expect_equal(ffirst(xNA, f, na.rm = FALSE), BY(xNA, f, basefirst))
@@ -153,6 +157,10 @@ test_that("flast performs like baselast (defined above)", {
   expect_equal(flast(m, na.rm = FALSE), dapply(m, baselast))
   expect_equal(flast(mNA, na.rm = FALSE), dapply(mNA, baselast))
   expect_equal(flast(mNA), dapply(mNA, baselast, na.rm = TRUE))
+  expect_equal(flast(data, drop = FALSE), dapply(data, baselast, na.rm = TRUE, drop = FALSE))
+  expect_equal(flast(data, na.rm = FALSE, drop = FALSE), dapply(data, baselast, drop = FALSE))
+  expect_equal(flast(dataNA, na.rm = FALSE, drop = FALSE), dapply(dataNA, baselast, drop = FALSE))
+  expect_equal(flast(dataNA, drop = FALSE), dapply(dataNA, baselast, na.rm = TRUE, drop = FALSE))
   expect_equal(flast(x, f), BY(x, f, baselast, na.rm = TRUE))
   expect_equal(flast(x, f, na.rm = FALSE), BY(x, f, baselast))
   expect_equal(flast(xNA, f, na.rm = FALSE), BY(xNA, f, baselast))
